/* eslint-disable @typescript-eslint/no-non-null-assertion */
import { createOutdir, saveFile } from "./integrations.js";
import { getCssPartList, getCssPropertyList, getTagList, config } from "./cem-utilities.js";
export function generateCustomDataFile(customElementsManifest) {
    const htmlTags = config.htmlFileName
        ? getTagList(customElementsManifest)
        : [];
    const cssProperties = config.cssFileName
        ? getCssPropertyList(customElementsManifest)
        : [];
    const cssParts = config.cssFileName
        ? getCssPartList(customElementsManifest)
        : [];
    saveCustomDataFiles(config, htmlTags, cssProperties, cssParts);
}
function saveCustomDataFiles(config, tags, cssProperties, cssParts) {
    createOutdir(config.outdir);
    if (config.htmlFileName) {
        saveFile(config.outdir, config.htmlFileName, getCustomHtmlDataFileContents(tags));
    }
    if (config.cssFileName) {
        saveFile(config.outdir, config.cssFileName, getCustomCssDataFileContents(cssProperties, cssParts));
    }
}
function getCustomHtmlDataFileContents(tags) {
    return `{
      "version": 1.1,
      "tags": ${JSON.stringify(tags)}
    }`;
}
function getCustomCssDataFileContents(properties, parts) {
    return `{
      "version": 1.1,
      "properties": ${JSON.stringify(properties)},
      "pseudoElements": ${JSON.stringify(parts)}
    }`;
}
